@@ -15,9 +15,9 @@ from fo2xfc import DOCXConverter, RTFConverter, ODTConverter, WMLConverter, xfc_
 def availableFormats():
 
     formats = []
-    if xinc_available():
+    if xinc_available:
         formats.append('pdf')
-    if xfc_available():
+    if xfc_available:
         formats.extend(['rtf', 'docx', 'odt', 'wml'])
 
     return formats
