@@ -5,9 +5,7 @@
 ##########################################################################
 
 import os
-import sys
 
-from config import java
 from util import newTempfile, runcmd
 from logger import LOG
 
